# Sample 1

## Summary

Summary is required.
You can write summary in multilines.

## Rows

### Categories

- Function 1
- Function 2

### Description

Morning

### Value

Example

---

### Categories

- Category 1

### Description

Noon

### Value

Example

---

### Categories

- Category 1
- Category 3

### Description

Evening

### Value

Example

---

### Categories

- Category 1
- Category 3

### Description

Night

### Value

Example
